@@ -96,7 +96,7 @@ var equalsOperatorScenarios = []expressionScenario{
 		document:   "{a: { b: {things: \"\"}, f: [1], g: [] }}",
 		expression: ".. | select(. == \"\")",
 		expected: []string{
-			"D0, P[a b things], (!!str)::\"\"\n",
+			"D0, P[a b things], (!!str)::\n",
 		},
 	},
 	{
@@ -186,5 +186,5 @@ func TestEqualOperatorScenarios(t *testing.T) {
 	for _, tt := range equalsOperatorScenarios {
 		testScenario(t, &tt)
 	}
-	documentScenarios(t, "Equals", equalsOperatorScenarios)
+	documentScenarios(t, "equals", equalsOperatorScenarios)
 }
