@@ -21,29 +21,25 @@ func multiplyOperator(d *dataTreeNavigator, context Context, expressionNode *Exp
 	return crossFunction(d, context, expressionNode, multiply(expressionNode.Operation.Preferences.(multiplyPreferences)), false)
 }
 
-func getNewBlankNode(lhs *yaml.Node, rhs *yaml.Node) *yaml.Node {
-
-	blankNode := &yaml.Node{}
-
-	if lhs.HeadComment != "" {
-		blankNode.HeadComment = lhs.HeadComment
-	} else if rhs.HeadComment != "" {
-		blankNode.HeadComment = rhs.HeadComment
+func getComments(lhs *CandidateNode, rhs *CandidateNode) (leadingContent string, headComment string, footComment string) {
+	leadingContent = rhs.LeadingContent
+	headComment = rhs.Node.HeadComment
+	footComment = rhs.Node.FootComment
+	if lhs.Node.HeadComment != "" || lhs.LeadingContent != "" {
+		headComment = lhs.Node.HeadComment
+		leadingContent = lhs.LeadingContent
 	}
 
-	if lhs.FootComment != "" {
-		blankNode.FootComment = lhs.FootComment
-	} else if rhs.FootComment != "" {
-		blankNode.FootComment = rhs.FootComment
+	if lhs.Node.FootComment != "" {
+		footComment = lhs.Node.FootComment
 	}
-
-	return blankNode
+	return leadingContent, headComment, footComment
 }
 
 func multiply(preferences multiplyPreferences) func(d *dataTreeNavigator, context Context, lhs *CandidateNode, rhs *CandidateNode) (*CandidateNode, error) {
 	return func(d *dataTreeNavigator, context Context, lhs *CandidateNode, rhs *CandidateNode) (*CandidateNode, error) {
 		// need to do this before unWrapping the potential document node
-		newBlankNode := getNewBlankNode(lhs.Node, rhs.Node)
+		leadingContent, headComment, footComment := getComments(lhs, rhs)
 		lhs.Node = unwrapDoc(lhs.Node)
 		rhs.Node = unwrapDoc(rhs.Node)
 		log.Debugf("Multipling LHS: %v", lhs.Node.Tag)
@@ -56,15 +52,10 @@ func multiply(preferences multiplyPreferences) func(d *dataTreeNavigator, contex
 			if err != nil {
 				return nil, err
 			}
-			newBlank.Node.HeadComment = newBlankNode.HeadComment
-			newBlank.Node.FootComment = newBlankNode.FootComment
+			newBlank.LeadingContent = leadingContent
+			newBlank.Node.HeadComment = headComment
+			newBlank.Node.FootComment = footComment
 
-			// var newBlank = lhs.CreateChild(nil, newBlankNode)
-			// log.Debugf("merge - merge lhs into blank")
-			// var newThing, err = mergeObjects(d, context.WritableClone(), newBlank, lhs, multiplyPreferences{})
-			// if err != nil {
-			// 	return nil, err
-			// }
 			return mergeObjects(d, context.WritableClone(), &newBlank, rhs, preferences)
 		} else if lhs.Node.Tag == "!!int" && rhs.Node.Tag == "!!int" {
 			return multiplyIntegers(lhs, rhs)
