@@ -35,33 +35,28 @@ We then need to update the first array. We will use the relative update (|=) bec
 We set the current element of the first array as $cur. Now we multiply (merge) $cur with the matching entry in $two, by passing $two through a select filter.
 `
 
-var docWithHeader = `
-# here
+var docWithHeader = `# here
 
 a: apple
 `
 
-var nodeWithHeader = `
-# here
-a: apple
+var nodeWithHeader = `node:
+  # here
+  a: apple
 `
 
-var docNoComments = `
-b: banana
+var docNoComments = `b: banana
 `
 
-var docWithFooter = `
-a: apple
+var docWithFooter = `a: apple
 
 # footer
 `
 
-var nodeWithFooter = `
-a: apple
+var nodeWithFooter = `a: apple
 # footer`
 
-var document = `
-a: &cat {name: cat}
+var document = `a: &cat {name: cat}
 b: {name: dog}
 c: 
   <<: *cat
@@ -89,9 +84,9 @@ var multiplyOperatorScenarios = []expressionScenario{
 		skipDoc:    true,
 		document:   nodeWithHeader,
 		document2:  docNoComments,
-		expression: `select(fi == 0) * select(fi == 1)`,
+		expression: `(select(fi == 0) | .node) * select(fi == 1)`,
 		expected: []string{
-			"D0, P[], (!!map)::# here\na: apple\nb: banana\n",
+			"D0, P[node], (!!map)::# here\na: apple\nb: banana\n",
 		},
 	},
 	{
@@ -107,7 +102,7 @@ var multiplyOperatorScenarios = []expressionScenario{
 		skipDoc:    true,
 		document:   docNoComments,
 		document2:  nodeWithHeader,
-		expression: `select(fi == 0) * select(fi == 1)`,
+		expression: `select(fi == 0) * (select(fi == 1) | .node)`,
 		expected: []string{
 			"D0, P[], (!!map)::b: banana\n# here\na: apple\n",
 		},
@@ -429,5 +424,5 @@ func TestMultiplyOperatorScenarios(t *testing.T) {
 	for _, tt := range multiplyOperatorScenarios {
 		testScenario(t, &tt)
 	}
-	documentScenarios(t, "Multiply (Merge)", multiplyOperatorScenarios)
+	documentScenarios(t, "multiply-merge", multiplyOperatorScenarios)
 }
