@@ -26,6 +26,20 @@ type expressionScenario struct {
 	dontFormatInputForDoc bool // dont format input doc for documentation generation
 }
 
+func readDocumentWithLeadingContent(content string, fakefilename string, fakeFileIndex int) (*list.List, error) {
+	reader, firstFileLeadingContent, err := processReadStream(bufio.NewReader(strings.NewReader(content)))
+	if err != nil {
+		return nil, err
+	}
+
+	inputs, err := readDocuments(reader, fakefilename, fakeFileIndex)
+	if err != nil {
+		return nil, err
+	}
+	inputs.Front().Value.(*CandidateNode).LeadingContent = firstFileLeadingContent
+	return inputs, nil
+}
+
 func testScenario(t *testing.T, s *expressionScenario) {
 	var err error
 
@@ -37,15 +51,17 @@ func testScenario(t *testing.T, s *expressionScenario) {
 	inputs := list.New()
 
 	if s.document != "" {
-		inputs, err = readDocuments(strings.NewReader(s.document), "sample.yml", 0)
+		inputs, err = readDocumentWithLeadingContent(s.document, "sample.yml", 0)
+
 		if err != nil {
 			t.Error(err, s.document, s.expression)
 			return
 		}
+
 		if s.document2 != "" {
-			moreInputs, err := readDocuments(strings.NewReader(s.document2), "another.yml", 1)
+			moreInputs, err := readDocumentWithLeadingContent(s.document2, "another.yml", 1)
 			if err != nil {
-				t.Error(err, s.document, s.expression)
+				t.Error(err, s.document2, s.expression)
 				return
 			}
 			inputs.PushBackList(moreInputs)
@@ -71,14 +87,31 @@ func testScenario(t *testing.T, s *expressionScenario) {
 		t.Error(fmt.Errorf("%v: %v", err, s.expression))
 		return
 	}
-	test.AssertResultComplexWithContext(t, s.expected, resultsToString(context.MatchingNodes), fmt.Sprintf("desc: %v\nexp: %v\ndoc: %v", s.description, s.expression, s.document))
+	test.AssertResultComplexWithContext(t, s.expected, resultsToString(t, context.MatchingNodes), fmt.Sprintf("desc: %v\nexp: %v\ndoc: %v", s.description, s.expression, s.document))
 }
 
-func resultsToString(results *list.List) []string {
+func resultsToString(t *testing.T, results *list.List) []string {
 	var pretty []string = make([]string, 0)
+
 	for el := results.Front(); el != nil; el = el.Next() {
 		n := el.Value.(*CandidateNode)
-		pretty = append(pretty, NodeToString(n))
+		var valueBuffer bytes.Buffer
+		printer := NewPrinterWithSingleWriter(bufio.NewWriter(&valueBuffer), YamlOutputFormat, true, false, 4, true)
+
+		err := printer.PrintResults(n.AsList())
+		if err != nil {
+			t.Error(err)
+			return nil
+		}
+
+		tag := n.Node.Tag
+		if n.Node.Kind == yaml.DocumentNode {
+			tag = "doc"
+		} else if n.Node.Kind == yaml.AliasNode {
+			tag = "alias"
+		}
+		output := fmt.Sprintf(`D%v, P%v, (%v)::%v`, n.Document, n.Path, tag, valueBuffer.String())
+		pretty = append(pretty, output)
 	}
 	return pretty
 }
@@ -227,13 +260,14 @@ func documentOutput(t *testing.T, w *bufio.Writer, s expressionScenario, formatt
 	inputs := list.New()
 
 	if s.document != "" {
-		inputs, err = readDocuments(strings.NewReader(formattedDoc), "sample.yml", 0)
+
+		inputs, err = readDocumentWithLeadingContent(formattedDoc, "sample.yml", 0)
 		if err != nil {
 			t.Error(err, s.document, s.expression)
 			return
 		}
 		if s.document2 != "" {
-			moreInputs, err := readDocuments(strings.NewReader(formattedDoc2), "another.yml", 1)
+			moreInputs, err := readDocumentWithLeadingContent(formattedDoc2, "another.yml", 1)
 			if err != nil {
 				t.Error(err, s.document, s.expression)
 				return
